@@ -9,7 +9,6 @@ import functools
 import logging
 import os
 import time
-import typing
 
 
 def get_current_str_time() -> str:
@@ -40,7 +39,7 @@ def time_it(method):
     return waapper
 
 
-def quick_sort(arr: typing.List[int]) -> typing.List[int]:
+def quick_sort(arr: list) -> list:
     if len(arr) < 2:
         return arr
     temp = arr[0]
